========
Moccasin
========

.. toctree::
    :maxdepth: 3

    Overview <index.rst>

.. toctree::
    :caption: Getting Started
    :maxdepth: 3

    installing_moccasin.rst
    quickstart.rst

.. toctree::
    :caption: Core Concepts
    :maxdepth: 3

    moccasin.toml <core_concepts/moccasin_toml.rst>
    core_concepts/project.rst
    core_concepts/networks.rst
    core_concepts/dependencies.rst 
    core_concepts/named_contracts.rst
    core_concepts/testing.rst
    Wallet <core_concepts/wallet.rst>
    Scripting (run) <core_concepts/script.rst>
    core_concepts/deployments.rst

.. toctree::
    :caption: How-to Guides
    :maxdepth: 3

    Contract Verification <how-tos/verify_contracts.rst>
    Deploy with MetaMask <how-tos/metamask_deployment.rst>
    Using Vyper Commands <how-tos/vyper_subcommand.rst>
    Format Code <how-tos/code_formatting.rst>
    Stateless Fuzzing <how-tos/stateless_fuzzing.rst>
    Stateful Fuzzing <how-tos/stateful_fuzzing.rst>
    how-tos/juypter_notebooks.rst
    Pass Compiler Args through the CLI <how-tos/compiler_args_to_cli.rst>
    

.. toctree::
    :caption: Tutorials
    :maxdepth: 3

    ZKsync <tutorials/zksync-getting-started.rst>

.. toctree::
    :caption: Reference
    :maxdepth: 3

    cli_commands.rst
    class_reference.rst
    all_moccasin_toml_parameters.rst
    explorer_network_defaults.rst
    common_errors.rst

